.. OpenERP Web documentation master file, created by
   sphinx-quickstart on Fri Mar 18 16:31:55 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to OpenERP Web's documentation!
=======================================

Contents:

.. toctree::
    :maxdepth: 1

    module
    widget


    async
    rpc
    qweb
    client_action

    guidelines

    testing

    search_view
    list_view
    form_view

    changelog-7.0

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
